import { Component, NgModule, ViewChild, ViewContainerRef } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { CanhcamModule, FieldType, FieldWrapper } from 'ngx-cc-template-core';
import { CommonModule } from '@angular/common';

class CanhcamFieldCheckbox extends FieldType {
    /**
     * @param {?} model
     * @param {?} field
     * @return {?}
     */
    static createControl(model, field) {
        return new FormControl({ value: model ? 'on' : undefined, disabled: field.templateOptions.disabled }, field.validators ? field.validators.validation : undefined, field.asyncValidators ? field.asyncValidators.validation : undefined);
    }
}
CanhcamFieldCheckbox.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-field-checkbox',
                template: `
    <label class="custom-control custom-checkbox">
      <input type="checkbox" [formControl]="formControl"
        *ngIf="!to.hidden" value="on"
        [canhcamAttributes]="field" class="custom-control-input">
        {{ to.label }}
        <span class="custom-control-indicator"></span>
    </label>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamFieldCheckbox.ctorParameters = () => [];

class CanhcamFieldMultiCheckbox extends FieldType {
    /**
     * @param {?} model
     * @param {?} field
     * @return {?}
     */
    static createControl(model, field) {
        let /** @type {?} */ controlGroupConfig = field.templateOptions.options.reduce((previous, option) => {
            previous[option.key] = new FormControl(model ? model[option.key] : undefined);
            return previous;
        }, {});
        return new FormGroup(controlGroupConfig, field.validators ? field.validators.validation : undefined, field.asyncValidators ? field.asyncValidators.validation : undefined);
    }
}
CanhcamFieldMultiCheckbox.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-field-multicheckbox',
                template: `
    <div *ngFor="let option of to.options" class="checkbox">
      <label class="custom-control custom-checkbox">
        <input type="checkbox" [value]="option.value" [formControl]="formControl.get(option.key)"
        [canhcamAttributes]="field" class="custom-control-input">
        {{ option.value }}
        <span class="custom-control-indicator"></span>
      </label>
    </div>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamFieldMultiCheckbox.ctorParameters = () => [];

class CanhcamFieldInput extends FieldType {
    /**
     * @return {?}
     */
    get type() {
        return this.to.type || 'text';
    }
}
CanhcamFieldInput.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-field-input',
                template: `
    <input [type]="type" [formControl]="formControl" class="form-control" [canhcamAttributes]="field" [class.is-invalid]="showError">
  `,
                host: {
                    '[class.d-inline-flex]': 'to.addonLeft || to.addonRight',
                },
            },] },
];
/**
 * @nocollapse
 */
CanhcamFieldInput.ctorParameters = () => [];

class CanhcamFieldRadio extends FieldType {
}
CanhcamFieldRadio.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-field-radio',
                template: `
    <div [formGroup]="form">
      <div *ngFor="let option of to.options" class="radio">
        <label class="custom-control custom-radio">
          <input [name]="id" type="radio" [value]="option.key" [formControl]="formControl"
          [canhcamAttributes]="field" class="custom-control-input">
          {{ option.value }}
          <span class="custom-control-indicator"></span>
        </label>
      </div>
    </div>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamFieldRadio.ctorParameters = () => [];

class CanhcamFieldTextArea extends FieldType {
}
CanhcamFieldTextArea.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-field-textarea',
                template: `
    <textarea [name]="key" [formControl]="formControl" [cols]="to.cols"
      [rows]="to.rows" class="form-control" [class.is-invalid]="showError"
      [canhcamAttributes]="field">
    </textarea>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamFieldTextArea.ctorParameters = () => [];

class CanhcamFieldSelect extends FieldType {
    /**
     * @return {?}
     */
    get labelProp() { return this.to.labelProp || 'label'; }
    /**
     * @return {?}
     */
    get valueProp() { return this.to.valueProp || 'value'; }
    /**
     * @return {?}
     */
    get groupProp() { return this.to.groupProp || 'group'; }
    /**
     * @return {?}
     */
    get selectOptions() {
        let /** @type {?} */ options = [];
        this.to.options.map((option) => {
            if (!option[this.groupProp]) {
                options.push(option);
            }
            else {
                let /** @type {?} */ filteredOption = options.filter((filteredOption) => {
                    return filteredOption.label === option[this.groupProp];
                });
                if (filteredOption[0]) {
                    filteredOption[0].group.push({
                        label: option[this.labelProp],
                        value: option[this.valueProp],
                    });
                }
                else {
                    options.push({
                        label: option[this.groupProp],
                        group: [{ value: option[this.valueProp], label: option[this.labelProp] }],
                    });
                }
            }
        });
        return options;
    }
}
CanhcamFieldSelect.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-field-select',
                template: `
    <select [formControl]="formControl" class="form-control" [class.is-invalid]="showError" [canhcamAttributes]="field">
      <option value="" *ngIf="to.placeholder">{{ to.placeholder }}</option>
      <ng-container *ngFor="let item of selectOptions">
       <optgroup *ngIf="item.group" label="{{item.label}}">
         <option *ngFor="let child of item.group" [value]="child.value" [disabled]="item.disabled">
           {{ child.label }}
         </option>
       </optgroup>
       <option *ngIf="!item.group" [value]="item.value" [disabled]="item.disabled">{{ item.label }}</option>
      </ng-container>
    </select>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamFieldSelect.ctorParameters = () => [];

class CanhcamWrapperFieldset extends FieldWrapper {
}
CanhcamWrapperFieldset.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-wrapper-fieldset',
                template: `
    <div class="form-group" [class.has-error]="showError">
      <ng-template #fieldComponent></ng-template>
    </div>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamWrapperFieldset.ctorParameters = () => [];
CanhcamWrapperFieldset.propDecorators = {
    'fieldComponent': [{ type: ViewChild, args: ['fieldComponent', { read: ViewContainerRef },] },],
};

class CanhcamWrapperLabel extends FieldWrapper {
}
CanhcamWrapperLabel.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-wrapper-label',
                template: `
    <label [attr.for]="id" class="form-control-label">
      {{ to.label }}
      {{ to.required ? '*' : '' }}
    </label>
    <ng-template #fieldComponent></ng-template>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamWrapperLabel.ctorParameters = () => [];
CanhcamWrapperLabel.propDecorators = {
    'fieldComponent': [{ type: ViewChild, args: ['fieldComponent', { read: ViewContainerRef },] },],
};

class CanhcamWrapperDescription extends FieldWrapper {
}
CanhcamWrapperDescription.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-wrapper-description',
                template: `
    <ng-template #fieldComponent></ng-template>
    <div>
      <small class="text-muted">{{ to.description }}</small>
    </div>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamWrapperDescription.ctorParameters = () => [];
CanhcamWrapperDescription.propDecorators = {
    'fieldComponent': [{ type: ViewChild, args: ['fieldComponent', { read: ViewContainerRef },] },],
};

class CanhcamWrapperValidationMessages extends FieldWrapper {
    /**
     * @return {?}
     */
    get validationId() {
        return this.field.id + '-message';
    }
}
CanhcamWrapperValidationMessages.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-wrapper-validation-messages',
                template: `
    <ng-template #fieldComponent></ng-template>
    <div>
      <small class="text-danger invalid-feedback" [style.display]="'block'" *ngIf="showError" role="alert" [id]="validationId">
        <canhcam-validation-message [fieldForm]="formControl" [field]="field"></canhcam-validation-message>
      </small>
    </div>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamWrapperValidationMessages.ctorParameters = () => [];
CanhcamWrapperValidationMessages.propDecorators = {
    'fieldComponent': [{ type: ViewChild, args: ['fieldComponent', { read: ViewContainerRef },] },],
};

class CanhcamWrapperAddons extends FieldWrapper {
    /**
     * @param {?} $event
     * @return {?}
     */
    addonRightClick($event) {
        if (this.to.addonRight.onClick) {
            this.to.addonRight.onClick(this.to, this, $event);
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    addonLeftClick($event) {
        if (this.to.addonLeft.onClick) {
            this.to.addonLeft.onClick(this.to, this, $event);
        }
    }
}
CanhcamWrapperAddons.decorators = [
    { type: Component, args: [{
                selector: 'canhcam-wrapper-addons',
                template: `
    <div class="input-group">
      <div class="input-group-addon"
        *ngIf="to.addonLeft"
        [ngStyle]="{cursor: to.addonLeft.onClick ? 'pointer' : 'inherit'}"
        (click)="addonLeftClick($event)">
        <i [ngClass]="to.addonLeft.class" *ngIf="to.addonLeft.class"></i>
        <span *ngIf="to.addonLeft.text">{{ to.addonLeft.text }}</span>
      </div>
      <ng-template #fieldComponent></ng-template>
      <div class="input-group-addon"
        *ngIf="to.addonRight"
        [ngStyle]="{cursor: to.addonRight.onClick ? 'pointer' : 'inherit'}"
        (click)="addonRightClick($event)">
        <i [ngClass]="to.addonRight.class" *ngIf="to.addonRight.class"></i>
        <span *ngIf="to.addonRight.text">{{ to.addonRight.text }}</span>
      </div>
    </div>
  `,
            },] },
];
/**
 * @nocollapse
 */
CanhcamWrapperAddons.ctorParameters = () => [];
CanhcamWrapperAddons.propDecorators = {
    'fieldComponent': [{ type: ViewChild, args: ['fieldComponent', { read: ViewContainerRef },] },],
};

class TemplateDescription {
    /**
     * @param {?} fc
     * @return {?}
     */
    run(fc) {
        fc.templateManipulators.postWrapper.push((field) => {
            if (field && field.templateOptions && field.templateOptions.description) {
                return 'description';
            }
        });
    }
}

class TemplateValidation {
    /**
     * @param {?} fc
     * @return {?}
     */
    run(fc) {
        fc.templateManipulators.postWrapper.push((field) => {
            if (field && field.validators) {
                return 'validation-message';
            }
        });
    }
}

class TemplateAddons {
    /**
     * @param {?} fc
     * @return {?}
     */
    run(fc) {
        fc.templateManipulators.postWrapper.push((field) => {
            if (field && field.templateOptions && (field.templateOptions.addonLeft || field.templateOptions.addonRight)) {
                return 'addons';
            }
        });
    }
}

const FIELD_TYPE_COMPONENTS = [
    // types
    CanhcamFieldInput,
    CanhcamFieldCheckbox,
    CanhcamFieldRadio,
    CanhcamFieldSelect,
    CanhcamFieldTextArea,
    CanhcamFieldMultiCheckbox,
    // wrappers
    CanhcamWrapperLabel,
    CanhcamWrapperDescription,
    CanhcamWrapperValidationMessages,
    CanhcamWrapperFieldset,
    CanhcamWrapperAddons,
];
const BOOTSTRAP_CANHCAM_CONFIG = {
    types: [
        {
            name: 'input',
            component: CanhcamFieldInput,
            wrappers: ['fieldset', 'label'],
        },
        {
            name: 'checkbox',
            component: CanhcamFieldCheckbox,
            wrappers: ['fieldset'],
        },
        {
            name: 'radio',
            component: CanhcamFieldRadio,
            wrappers: ['fieldset', 'label'],
        },
        {
            name: 'select',
            component: CanhcamFieldSelect,
            wrappers: ['fieldset', 'label'],
        },
        {
            name: 'textarea',
            component: CanhcamFieldTextArea,
            wrappers: ['fieldset', 'label'],
            defaultOptions: {
                templateOptions: {
                    cols: 1,
                    rows: 1,
                },
            },
        },
        {
            name: 'multicheckbox',
            component: CanhcamFieldMultiCheckbox,
            wrappers: ['fieldset', 'label'],
        },
    ],
    wrappers: [
        { name: 'label', component: CanhcamWrapperLabel },
        { name: 'description', component: CanhcamWrapperDescription },
        { name: 'validation-message', component: CanhcamWrapperValidationMessages },
        { name: 'fieldset', component: CanhcamWrapperFieldset },
        { name: 'addons', component: CanhcamWrapperAddons },
    ],
    manipulators: [
        { class: TemplateDescription, method: 'run' },
        { class: TemplateValidation, method: 'run' },
        { class: TemplateAddons, method: 'run' },
    ],
};

class CanhcamBootstrapModule {
}
CanhcamBootstrapModule.decorators = [
    { type: NgModule, args: [{
                declarations: FIELD_TYPE_COMPONENTS,
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    CanhcamModule.forRoot(BOOTSTRAP_CANHCAM_CONFIG),
                ],
            },] },
];
/**
 * @nocollapse
 */
CanhcamBootstrapModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { CanhcamBootstrapModule, CanhcamFieldCheckbox, CanhcamFieldMultiCheckbox, CanhcamFieldInput, CanhcamFieldRadio, CanhcamFieldTextArea, CanhcamFieldSelect, CanhcamWrapperFieldset, CanhcamWrapperLabel, CanhcamWrapperDescription, CanhcamWrapperValidationMessages, TemplateAddons as ɵf, TemplateDescription as ɵd, TemplateValidation as ɵe, BOOTSTRAP_CANHCAM_CONFIG as ɵb, FIELD_TYPE_COMPONENTS as ɵa, CanhcamWrapperAddons as ɵc };
//# sourceMappingURL=ngx-cc-template-bootstrap.js.map
